.. currentmodule:: {{ info['modulename'] }}

:class:`{{ classname }}`
{{ '=' * (classname|count + 9 ) }}

.. inheritance-diagram:: {{ classname }}
    :parts: 1
    
.. autoclass:: {{ classname }}
    :members:
    :undoc-members:
    :show-inheritance: